(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 8.1' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[     82050,       2169]
NotebookOptionsPosition[     77477,       2014]
NotebookOutlinePosition[     77925,       2031]
CellTagsIndexPosition[     77882,       2028]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
 "Importing data from CERN ROOT files to ",
 StyleBox["Mathematica",
  FontSlant->"Italic"]
}], "Subsubtitle",
 CellChangeTimes->{{3.495466839921068*^9, 3.495466844600644*^9}, 
   3.495469095248324*^9, {3.498484621161235*^9, 3.4984846235363293`*^9}, {
   3.500213655690717*^9, 3.5002136750468707`*^9}}],

Cell["\<\
Ken Hsieh
Technical Staff Member
Wolfram Research Inc\
\>", "Text",
 CellChangeTimes->{{3.500213676609111*^9, 3.5002136980742884`*^9}}],

Cell["March 8, 2011", "Text",
 CellChangeTimes->{{3.5002137017767973`*^9, 3.5002137060104675`*^9}, {
  3.5063494708196487`*^9, 3.5063494741628428`*^9}, {3.5085887091940355`*^9, 
  3.5085887116466265`*^9}, {3.5085888046263895`*^9, 3.5085888047826056`*^9}}],

Cell["\<\
This notebook demonstrates some examples of importing data from ROOT files.\
\>", "Text",
 CellChangeTimes->{{3.50022261625*^9, 3.50022263690625*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{"$Version", "\[IndentingNewLine]", "$UserBaseDirectory"}], \
"Input",
 CellChangeTimes->{{3.508588303765631*^9, 3.5085883072332044`*^9}, {
  3.508588690697944*^9, 3.508588705366743*^9}}],

Cell[BoxData["\<\"8.0 for Microsoft Windows (32-bit) (November 7, \
2010)\"\>"], "Output",
 CellChangeTimes->{
  3.5085883084827805`*^9, 3.508588539888636*^9, 3.5085885701596146`*^9, {
   3.5085886941347623`*^9, 3.5085887144897575`*^9}}],

Cell[BoxData["\<\"C:\\\\Documents and Settings\\\\kenh\\\\Application \
Data\\\\Mathematica\"\>"], "Output",
 CellChangeTimes->{
  3.5085883084827805`*^9, 3.508588539888636*^9, 3.5085885701596146`*^9, {
   3.5085886941347623`*^9, 3.5085887144897575`*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "make", " ", "sure", " ", "that", " ", "the", " ", "necessary", " ", 
    "converter", " ", "files", " ", "are", " ", "present"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"dir", " ", "=", " ", 
     RowBox[{"FileNameJoin", "[", 
      RowBox[{"{", 
       RowBox[{
       "$UserBaseDirectory", ",", " ", "\"\<SystemFiles\>\"", ",", 
        "\"\<Formats\>\"", ",", "\"\<ROOT\>\""}], "}"}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"FileExistsQ", "[", 
      RowBox[{"FileNameJoin", "[", 
       RowBox[{"{", 
        RowBox[{"dir", ",", " ", 
         RowBox[{"ReleaseHold", "[", "#", "]"}]}], "}"}], "]"}], "]"}], "&"}],
     "/@", 
    RowBox[{"{", 
     RowBox[{"\"\<Import.m\>\"", ",", "\"\<Converter.m\>\"", ",", 
      RowBox[{"Hold", "[", 
       RowBox[{"Sequence", "[", 
        RowBox[{
        "\"\<Binaries\>\"", ",", "$SystemID", ",", "\"\<ROOT.exe\>\""}], 
        "]"}], "]"}]}], "}"}]}]}]}]], "Input",
 CellChangeTimes->{{3.50858831997888*^9, 3.5085885093052635`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"True", ",", "True", ",", "True"}], "}"}]], "Output",
 CellChangeTimes->{{3.50858844596738*^9, 3.5085884594784203`*^9}, {
   3.5085884895619626`*^9, 3.5085885096645164`*^9}, 3.508588539997974*^9, 
   3.5085885702689524`*^9, 3.508588716629917*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell["ROOT Importer Usage", "Section",
 CellChangeTimes->{{3.4954668113144627`*^9, 3.495466817275997*^9}, 
   3.49546816384711*^9, {3.4954690916971188`*^9, 3.495469092200037*^9}, {
   3.4984845952028*^9, 3.4984845974328814`*^9}}],

Cell[CellGroupData[{

Cell["File MetaInformation (from TKey Objects)", "Subsection",
 CellChangeTimes->{{3.4989230905372066`*^9, 3.498923099479878*^9}, {
  3.498926024797756*^9, 3.49892602895374*^9}}],

Cell[TextData[{
 "The wrappers to access TKey functionalities have the form:\n",
 StyleBox["  Import[ ",
  FontFamily->"Courier New"],
 StyleBox["file",
  FontFamily->"Courier New",
  FontSlant->"Italic"],
 StyleBox[", {\[OpenCurlyDoubleQuote]ROOT\[CloseCurlyDoubleQuote], \
\[OpenCurlyDoubleQuote]Keys\[CloseCurlyDoubleQuote]} ]",
  FontFamily->"Courier New"],
 "\nor simply as\n",
 StyleBox["  Import[ ",
  FontFamily->"Courier New"],
 StyleBox["file",
  FontFamily->"Courier New",
  FontSlant->"Italic"],
 StyleBox[", \[OpenCurlyDoubleQuote]ROOT\[CloseCurlyDoubleQuote] ]",
  FontFamily->"Courier New"],
 "\nand the output has the form:\n  { {name1, title1, class1},  {name2, \
title2, class2}, ... }"
}], "Text",
 CellChangeTimes->{{3.495468497648314*^9, 3.495468500528111*^9}, {
  3.495468563465575*^9, 3.495468647615963*^9}, {3.495468706668795*^9, 
  3.495468844049102*^9}, {3.498483935097855*^9, 3.498483937281838*^9}, {
  3.4984839819621143`*^9, 3.498484083096613*^9}, {3.4984847206013823`*^9, 
  3.498484782440452*^9}, {3.498496219124737*^9, 3.498496220755698*^9}, {
  3.498499361837543*^9, 3.498499364531248*^9}, {3.4984993962509413`*^9, 
  3.498499434835371*^9}, {3.4989260554207964`*^9, 3.4989261230883403`*^9}, {
  3.502723144944669*^9, 3.5027231818734217`*^9}},
 FontFamily->"Courier [ibm]",
 FontSize->10],

Cell[BoxData[
 RowBox[{
  RowBox[{"SetDirectory", "[", 
   RowBox[{"NotebookDirectory", "[", "]"}], "]"}], ";"}]], "Input"],

Cell[TextData[StyleBox["If this is the very first time ROOT converter runs, \
this call may take some time to complete because the converter is generating \
some needed libraries.  This library-generation happens only once and the \
libraries will persist in future sessions.",
 FontWeight->"Bold"]], "Text",
 CellChangeTimes->{{3.5062744872129283`*^9, 3.5062745411191783`*^9}, {
  3.506349700750132*^9, 3.506349742336961*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Import", "[", 
  RowBox[{"\"\<cernstaff.root\>\"", ",", 
   RowBox[{"{", 
    RowBox[{"\"\<ROOT\>\"", ",", "\"\<Keys\>\""}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.498923109779154*^9, 3.49892314827369*^9}, {
   3.498925962129364*^9, 3.498925976019189*^9}, {3.5000535056328926`*^9, 
   3.5000535485542183`*^9}, 3.50005358160067*^9, {3.500655039358465*^9, 
   3.5006550397177753`*^9}, 3.5008195639204717`*^9, {3.5008202017538743`*^9, 
   3.5008202105814905`*^9}, 3.500820371148447*^9, 3.5008261883184*^9, {
   3.5008296236747227`*^9, 3.500829624330948*^9}, {3.501081885140625*^9, 
   3.50108188640625*^9}, {3.5027231548641944`*^9, 3.502723192433421*^9}, {
   3.5062744836973033`*^9, 3.5062744853691783`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"\<\"T\"\>", ",", "\<\"CERN 1988 staff data\"\>", 
    ",", "\<\"TTree\"\>"}], "}"}], "}"}]], "Output",
 CellChangeTimes->{
  3.5010918172792263`*^9, 3.5010919531542263`*^9, 3.501092277868142*^9, 
   3.501092436410959*^9, 3.501181345703125*^9, 3.501181575*^9, 
   3.501181636984375*^9, 3.501181840828125*^9, 3.501181952796875*^9, {
   3.5011822334345217`*^9, 3.501182256611272*^9}, 3.5011823614153986`*^9, 
   3.501246415725645*^9, 3.501246732016182*^9, 3.501246928126903*^9, 
   3.501247656585518*^9, {3.5012489592103214`*^9, 3.501248964366275*^9}, 
   3.501265999195634*^9, 3.5014303851253357`*^9, 3.501617682053399*^9, 
   3.502723192855196*^9, 3.503166815893845*^9, 3.5032356242003736`*^9, 
   3.5063504095899305`*^9, 3.5068757819026623`*^9, 3.5068825081626873`*^9, 
   3.5072204513747435`*^9, 3.507228071235594*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Import", "[", 
  RowBox[{"\"\<demo.root\>\"", ",", "\"\<ROOT\>\""}], "]"}]], "Input",
 CellChangeTimes->{{3.501081903890625*^9, 3.501081932078125*^9}, {
   3.50108246184375*^9, 3.501082462921875*^9}, {3.5010825868135834`*^9, 
   3.5010825871812105`*^9}, 3.501082864111717*^9, {3.5010857877761917`*^9, 
   3.5010857929324093`*^9}, 3.501086688465247*^9, {3.501087223071333*^9, 
   3.5010872302742734`*^9}, {3.5010913457363834`*^9, 
   3.5010913810779557`*^9}, {3.5010916364727635`*^9, 
   3.5010916395351267`*^9}, {3.5010918217167263`*^9, 
   3.5010918399823513`*^9}, {3.5010919568573513`*^9, 
   3.5010919969667263`*^9}, {3.501092284852339*^9, 3.501092289899084*^9}, {
   3.501092476425559*^9, 3.5010924807066994`*^9}, {3.50118135365625*^9, 
   3.50118138303125*^9}, {3.501246421284595*^9, 3.501246422853285*^9}, {
   3.501246457867055*^9, 3.501246458004125*^9}, {3.5027231971666746`*^9, 
   3.502723210257324*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"\<\"h0\"\>", ",", "\<\"histo nr:0\"\>", ",", "\<\"TH1F\"\>"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"h1\"\>", ",", "\<\"histo nr:1\"\>", ",", "\<\"TH1F\"\>"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"h2\"\>", ",", "\<\"histo nr:2\"\>", ",", "\<\"TH1F\"\>"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"h3\"\>", ",", "\<\"histo nr:3\"\>", ",", "\<\"TH1F\"\>"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"h4\"\>", ",", "\<\"histo nr:4\"\>", ",", "\<\"TH1F\"\>"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"h5\"\>", ",", "\<\"histo nr:5\"\>", ",", "\<\"TH1F\"\>"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"h6\"\>", ",", "\<\"histo nr:6\"\>", ",", "\<\"TH1F\"\>"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"h7\"\>", ",", "\<\"histo nr:7\"\>", ",", "\<\"TH1F\"\>"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"h8\"\>", ",", "\<\"histo nr:8\"\>", ",", "\<\"TH1F\"\>"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"h9\"\>", ",", "\<\"histo nr:9\"\>", ",", "\<\"TH1F\"\>"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"h10\"\>", ",", "\<\"histo nr:10\"\>", ",", "\<\"TH1F\"\>"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"h11\"\>", ",", "\<\"histo nr:11\"\>", ",", "\<\"TH1F\"\>"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"h12\"\>", ",", "\<\"histo nr:12\"\>", ",", "\<\"TH1F\"\>"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"h13\"\>", ",", "\<\"histo nr:13\"\>", ",", "\<\"TH1F\"\>"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"h14\"\>", ",", "\<\"histo nr:14\"\>", ",", "\<\"TH1F\"\>"}], 
    "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.5010819078125*^9, 3.50108193259375*^9}, 
   3.501082045109375*^9, 3.50108225396875*^9, 3.5010824634375*^9, {
   3.5010825828309555`*^9, 3.5010825884219522`*^9}, 3.501082801691682*^9, 
   3.501082832955312*^9, {3.5010828644487085`*^9, 3.501082867023082*^9}, 
   3.501085342839347*^9, 3.5010856617144985`*^9, {3.5010857898543034`*^9, 
   3.5010858103854227`*^9}, 3.501086502578901*^9, {3.5010866858872375`*^9, 
   3.501086688855854*^9}, {3.501087215790269*^9, 3.5010872281493278`*^9}, 
   3.50108742023816*^9, 3.501089669403226*^9, {3.5010913433459425`*^9, 
   3.5010913814841876`*^9}, 3.501091539461485*^9, {3.5010916372227297`*^9, 
   3.5010916399569826`*^9}, {3.5010918182792263`*^9, 3.5010918409667263`*^9}, 
   3.5010918896854763`*^9, {3.5010919539979763`*^9, 3.5010919977323513`*^9}, {
   3.501092278868117*^9, 3.5010922903209486`*^9}, 3.5010924371609397`*^9, 
   3.501092481128564*^9, {3.50118134703125*^9, 3.50118138340625*^9}, 
   3.5011815756875*^9, 3.501181637484375*^9, 3.501181840890625*^9, {
   3.5011822342431903`*^9, 3.5011822571758137`*^9}, {3.501246418512735*^9, 
   3.501246423371105*^9}, 3.501246458780855*^9, 3.5012467327593565`*^9, 
   3.5012469295596924`*^9, 3.501247659772324*^9, 3.5012660000238066`*^9, 
   3.501430386140889*^9, 3.501617682865644*^9, 3.5027232106322355`*^9, 
   3.5031668162532153`*^9, 3.5063496844715915`*^9, 3.506349750569966*^9, 
   3.5063504097618093`*^9, 3.506875782183919*^9, 3.5068825085220532`*^9, 
   3.507220451591481*^9, 3.5072280714074664`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Import", "[", 
  RowBox[{"\"\<th2f.root\>\"", ",", "\"\<ROOT\>\""}], "]"}]], "Input",
 CellChangeTimes->{{3.5027232283936534`*^9, 3.5027232292215824`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", 
   RowBox[{"\<\"h2\"\>", ",", "\<\"xygaus + xygaus(5) + xylandau(10)\"\>", 
    ",", "\<\"TH2F\"\>"}], "}"}], "}"}]], "Output",
 CellChangeTimes->{3.5027232295964937`*^9, 3.503166816393839*^9, 
  3.5063497518198175`*^9, 3.5063504098399353`*^9, 3.5068757823557987`*^9, 
  3.506882508678299*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Interfaces to TTree Objects", "Subsection",
 CellChangeTimes->{{3.498483889952964*^9, 3.498483925567772*^9}, {
   3.498483956474862*^9, 3.498483959168501*^9}, {3.4984846990172873`*^9, 
   3.4984847009928627`*^9}, 3.5008241615575256`*^9}],

Cell[CellGroupData[{

Cell["Usage Information", "Subsubsection",
 CellChangeTimes->{{3.498483889952964*^9, 3.498483925567772*^9}, {
  3.498483956474862*^9, 3.498483959168501*^9}, {3.4984846990172873`*^9, 
  3.4984847009928627`*^9}, {3.498493103795794*^9, 3.498493110273582*^9}, {
  3.5008288737913947`*^9, 3.5008289083378277`*^9}, {3.5063504314341*^9, 
  3.506350433668518*^9}}],

Cell[TextData[{
 "The wrappers to access TTree functionalities have the forms:\n\nretrieve \
metadata (branch names, data types, etc) with \
\[OpenCurlyDoubleQuote]TTreeMetadata\[CloseCurlyDoubleQuote]:\n",
 StyleBox["  Import[ ",
  FontFamily->"Courier New"],
 StyleBox["file",
  FontFamily->"Courier New",
  FontSlant->"Italic"],
 StyleBox[", {\[OpenCurlyDoubleQuote]ROOT\[CloseCurlyDoubleQuote], \
\[OpenCurlyDoubleQuote]TTreeMetadata\[CloseCurlyDoubleQuote], ",
  FontFamily->"Courier New"],
 StyleBox["tree",
  FontFamily->"Courier New",
  FontSlant->"Italic"],
 StyleBox["} ]",
  FontFamily->"Courier New"],
 "\n  \nretrieve data from a TTree with \[OpenCurlyDoubleQuote]TTreeData\
\[CloseCurlyDoubleQuote]:\n",
 StyleBox["  Import[ ",
  FontFamily->"Courier New"],
 StyleBox["file",
  FontFamily->"Courier New",
  FontSlant->"Italic"],
 StyleBox[", {\[OpenCurlyDoubleQuote]ROOT\[CloseCurlyDoubleQuote], \
\[OpenCurlyDoubleQuote]TTreeData\[CloseCurlyDoubleQuote], ",
  FontFamily->"Courier New"],
 StyleBox["treet",
  FontFamily->"Courier New",
  FontSlant->"Italic"],
 StyleBox["} ],\n  Import[ ",
  FontFamily->"Courier New"],
 StyleBox["file",
  FontFamily->"Courier New",
  FontSlant->"Italic"],
 StyleBox[", {\[OpenCurlyDoubleQuote]ROOT\[CloseCurlyDoubleQuote], \
\[OpenCurlyDoubleQuote]TTreeData\[CloseCurlyDoubleQuote], ",
  FontFamily->"Courier New"],
 StyleBox["tree",
  FontFamily->"Courier New",
  FontSlant->"Italic"],
 StyleBox[", ",
  FontFamily->"Courier New"],
 StyleBox["branch",
  FontFamily->"Courier New",
  FontSlant->"Italic"],
 StyleBox["} ],",
  FontFamily->"Courier New"],
 "\n  \nuse the option \[OpenCurlyDoubleQuote]Range\[CloseCurlyDoubleQuote] \
to do a partial import:\n",
 StyleBox["  Import[ ",
  FontFamily->"Courier New"],
 StyleBox["file",
  FontFamily->"Courier New",
  FontSlant->"Italic"],
 StyleBox[", {\[OpenCurlyDoubleQuote]ROOT\[CloseCurlyDoubleQuote], \
\[OpenCurlyDoubleQuote]TTreeData\[CloseCurlyDoubleQuote], ",
  FontFamily->"Courier New"],
 StyleBox["treet",
  FontFamily->"Courier New",
  FontSlant->"Italic"],
 StyleBox["}, \[OpenCurlyDoubleQuote]Rage\[CloseCurlyDoubleQuote] -> {",
  FontFamily->"Courier New"],
 StyleBox["beg, end ",
  FontFamily->"Courier New",
  FontSlant->"Italic"],
 StyleBox["} ],\n  Import[ ",
  FontFamily->"Courier New"],
 StyleBox["file",
  FontFamily->"Courier New",
  FontSlant->"Italic"],
 StyleBox[", {\[OpenCurlyDoubleQuote]ROOT\[CloseCurlyDoubleQuote], \
\[OpenCurlyDoubleQuote]TTreeData\[CloseCurlyDoubleQuote], ",
  FontFamily->"Courier New"],
 StyleBox["tree",
  FontFamily->"Courier New",
  FontSlant->"Italic"],
 StyleBox[", ",
  FontFamily->"Courier New"],
 StyleBox["branch",
  FontFamily->"Courier New",
  FontSlant->"Italic"],
 StyleBox["}, \[OpenCurlyDoubleQuote]Range\[CloseCurlyDoubleQuote] -> {",
  FontFamily->"Courier New"],
 StyleBox["beg, end ",
  FontFamily->"Courier New",
  FontSlant->"Italic"],
 StyleBox["} ],",
  FontFamily->"Courier New"],
 "\n\nwhere:\n    ",
 StyleBox["tree",
  FontSlant->"Italic"],
 " is the name of the TTree object,\n    ",
 StyleBox["branch",
  FontSlant->"Italic"],
 " is the name of a TBranch object,\n    ",
 StyleBox["beg ",
  FontSlant->"Italic"],
 " is the starting index (1-indexed) when partially importing a branch,\n    \
end",
 StyleBox[" ",
  FontSlant->"Italic"],
 " is the ending index (1-indexed) when partially importing a branch."
}], "Text",
 CellChangeTimes->{{3.495468497648314*^9, 3.495468500528111*^9}, {
  3.495468563465575*^9, 3.495468647615963*^9}, {3.495468706668795*^9, 
  3.495468844049102*^9}, {3.498483935097855*^9, 3.498483937281838*^9}, {
  3.4984839819621143`*^9, 3.498484083096613*^9}, {3.4984847206013823`*^9, 
  3.498484782440452*^9}, {3.498496219124737*^9, 3.498496220755698*^9}, {
  3.498499361837543*^9, 3.498499364531248*^9}, {3.4984993962509413`*^9, 
  3.498499434835371*^9}, {3.5008263464196796`*^9, 3.5008264870218554`*^9}, {
  3.5008295347250137`*^9, 3.5008296060816483`*^9}, {3.502723394731903*^9, 
  3.502723395231797*^9}, {3.5027234285734673`*^9, 3.5027234339181404`*^9}},
 FontFamily->"Courier [ibm]",
 FontSize->10],

Cell["\<\
Note that, since NTuple inherits from TTree, we can also pass
the name of an NTuple object.\
\>", "Text",
 CellChangeTimes->{{3.495468497648314*^9, 3.495468500528111*^9}, {
  3.495468563465575*^9, 3.495468647615963*^9}, {3.495468706668795*^9, 
  3.495468844049102*^9}, {3.498483935097855*^9, 3.498483937281838*^9}, {
  3.4984839819621143`*^9, 3.498484083096613*^9}, {3.4984847206013823`*^9, 
  3.498484782440452*^9}, {3.498496219124737*^9, 3.498496220755698*^9}, {
  3.498499361837543*^9, 3.498499364531248*^9}, {3.4984993962509413`*^9, 
  3.498499434835371*^9}, {3.498931260561355*^9, 3.4989313169999533`*^9}},
 FontFamily->"Courier [ibm]",
 FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Importing the TKey information.\
\>", "Subsubsection",
 CellChangeTimes->{{3.498483889952964*^9, 3.498483925567772*^9}, {
  3.498483956474862*^9, 3.498483959168501*^9}, {3.4984846990172873`*^9, 
  3.4984847009928627`*^9}, {3.498493103795794*^9, 3.498493110273582*^9}, {
  3.5008288737913947`*^9, 3.5008289083378277`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "This", " ", "imports", " ", "the", " ", "metadata", " ", "of", " ", "a", 
    " ", "given", " ", "tree"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"Import", "[", 
   RowBox[{"\"\<cernstaff.root\>\"", ",", " ", 
    RowBox[{"{", 
     RowBox[{
     "\"\<ROOT\>\"", ",", " ", "\"\<TTreeMetadata\>\"", ",", " ", 
      "\"\<T\>\""}], "}"}]}], "]"}]}]], "Input",
 CellFrame->{{0, 0}, {0, 0.5}},
 CellChangeTimes->{{3.498484126665839*^9, 3.498484166433033*^9}, {
   3.4984845171400967`*^9, 3.498484517445868*^9}, {3.498484662021961*^9, 
   3.498484674276703*^9}, {3.498490503553673*^9, 3.498490506542944*^9}, 
   3.498496298032745*^9, {3.498499443423614*^9, 3.498499448203699*^9}, {
   3.500053598100459*^9, 3.500053673740116*^9}, {3.5006550480600305`*^9, 
   3.5006550594642363`*^9}, {3.502723466517523*^9, 3.502723469361764*^9}, {
   3.5070362937799206`*^9, 3.5070363043894997`*^9}}],

Cell[BoxData[
 TagBox[GridBox[{
    {"\<\"Category\"\>", "\<\"Category\"\>", "\<\"Int_t\"\>", "3354"},
    {"\<\"Flag\"\>", "\<\"Flag\"\>", "\<\"UInt_t\"\>", "3354"},
    {"\<\"Age\"\>", "\<\"Age\"\>", "\<\"Int_t\"\>", "3354"},
    {"\<\"Service\"\>", "\<\"Service\"\>", "\<\"Int_t\"\>", "3354"},
    {"\<\"Children\"\>", "\<\"Children\"\>", "\<\"Int_t\"\>", "3354"},
    {"\<\"Grade\"\>", "\<\"Grade\"\>", "\<\"Int_t\"\>", "3354"},
    {"\<\"Step\"\>", "\<\"Step\"\>", "\<\"Int_t\"\>", "3354"},
    {"\<\"Hrweek\"\>", "\<\"Hrweek\"\>", "\<\"Int_t\"\>", "3354"},
    {"\<\"Cost\"\>", "\<\"Cost\"\>", "\<\"Int_t\"\>", "3354"},
    {"\<\"Division\"\>", "\<\"Division\"\>", "\<\"Char_t\"\>", "3354"},
    {"\<\"Nation\"\>", "\<\"Nation\"\>", "\<\"Char_t\"\>", "3354"}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{
  3.5006550600110135`*^9, 3.500656198626927*^9, 3.5008195084123225`*^9, 
   3.500824219324999*^9, 3.500824513938337*^9, {3.500824611373966*^9, 
   3.5008246281236444`*^9}, 3.500829398370875*^9, 3.5010130809101486`*^9, 
   3.5016184130768976`*^9, 3.5027234702212877`*^9, 3.5032356317447853`*^9, 
   3.506349764568757*^9, 3.5063504099336877`*^9, 3.5070358128386683`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "import", " ", "the", " ", "branch", " ", "information", " ", "of", " ", 
    "a", " ", "TTree"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"header", " ", "=", " ", 
     RowBox[{"{", 
      RowBox[{
      "\"\<Name\>\"", ",", "\"\<Title\>\"", ",", "\"\<Data Type\>\"", ",", 
       " ", "\"\<Entries\>\""}], "}"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"branchinfo", "=", 
     RowBox[{"Import", "[", 
      RowBox[{"\"\<cernstaff.root\>\"", ",", " ", 
       RowBox[{"{", 
        RowBox[{
        "\"\<ROOT\>\"", ",", " ", "\"\<TTreeMetadata\>\"", ",", " ", 
         "\"\<T\>\""}], "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"Grid", "[", 
    RowBox[{
     RowBox[{"Join", "[", " ", 
      RowBox[{
       RowBox[{"{", "header", "}"}], ",", " ", "branchinfo"}], " ", "]"}], 
     ",", " ", 
     RowBox[{"Frame", "\[Rule]", " ", "All"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.507036309280218*^9, 3.5070363761877527`*^9}, {
  3.5070364352043204`*^9, 3.5070364497665405`*^9}}],

Cell[BoxData[
 TagBox[GridBox[{
    {"\<\"Name\"\>", "\<\"Title\"\>", "\<\"Data Type\"\>", "\<\"Entries\"\>"},
    {"\<\"Category\"\>", "\<\"Category\"\>", "\<\"Int_t\"\>", "3354"},
    {"\<\"Flag\"\>", "\<\"Flag\"\>", "\<\"UInt_t\"\>", "3354"},
    {"\<\"Age\"\>", "\<\"Age\"\>", "\<\"Int_t\"\>", "3354"},
    {"\<\"Service\"\>", "\<\"Service\"\>", "\<\"Int_t\"\>", "3354"},
    {"\<\"Children\"\>", "\<\"Children\"\>", "\<\"Int_t\"\>", "3354"},
    {"\<\"Grade\"\>", "\<\"Grade\"\>", "\<\"Int_t\"\>", "3354"},
    {"\<\"Step\"\>", "\<\"Step\"\>", "\<\"Int_t\"\>", "3354"},
    {"\<\"Hrweek\"\>", "\<\"Hrweek\"\>", "\<\"Int_t\"\>", "3354"},
    {"\<\"Cost\"\>", "\<\"Cost\"\>", "\<\"Int_t\"\>", "3354"},
    {"\<\"Division\"\>", "\<\"Division\"\>", "\<\"Char_t\"\>", "3354"},
    {"\<\"Nation\"\>", "\<\"Nation\"\>", "\<\"Char_t\"\>", "3354"}
   },
   AutoDelete->False,
   GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
  "Grid"]], "Output",
 CellChangeTimes->{{3.5070363666875706`*^9, 3.5070363765627604`*^9}, 
   3.507036418641693*^9, 3.5070364518290014`*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Importing one particular branch.", "Subsubsection",
 CellChangeTimes->{{3.498483889952964*^9, 3.498483925567772*^9}, {
  3.498483956474862*^9, 3.498483959168501*^9}, {3.4984846990172873`*^9, 
  3.4984847009928627`*^9}, {3.498493103795794*^9, 3.498493110273582*^9}, {
  3.5008288737913947`*^9, 3.500828924571995*^9}, {3.5008289592121763`*^9, 
  3.5008289884774265`*^9}, {3.502723510118806*^9, 3.5027235105094986`*^9}, {
  3.5063497847233295`*^9, 3.5063497853951488`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "This", " ", "imports", " ", "the", " ", "Age", " ", "branch", " ", "and", 
    " ", "plots", " ", "it", " ", "as", " ", "with", " ", 
    RowBox[{"Histogram", "[", "]"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"dat", "=", 
     RowBox[{"Import", "[", 
      RowBox[{"\"\<cernstaff.root\>\"", ",", " ", 
       RowBox[{"{", 
        RowBox[{
        "\"\<ROOT\>\"", ",", " ", "\"\<TTreeData\>\"", ",", " ", "\"\<T\>\"", 
         ",", " ", "\"\<Age\>\""}], "}"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Histogram", "[", "dat", "]"}]}]}]], "Input",
 CellFrame->{{0, 0}, {0, 0.5}},
 CellChangeTimes->{{3.498484262143279*^9, 3.498484294879013*^9}, {
   3.498490652197131*^9, 3.4984906525961943`*^9}, {3.498490786930372*^9, 
   3.498490795515463*^9}, 3.498496231941674*^9, {3.498496524980996*^9, 
   3.498496525560548*^9}, 3.49849671915097*^9, {3.4984967683226023`*^9, 
   3.4984967712906017`*^9}, {3.500826625592885*^9, 3.500826645232505*^9}, {
   3.5027235257465057`*^9, 3.5027235270123496`*^9}}],

Cell[BoxData[
 GraphicsBox[
  {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
   EdgeForm[Opacity[0.7]], {}, 
   {RGBColor[0.798413061722744, 0.824719615472648, 0.968322270542458], 
    EdgeForm[Opacity[0.7]], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            GrayLevel[0.5], 
            AbsoluteThickness[1.5], 
            Opacity[0.66]}], {}, {}], 
         RectangleBox[{20., 0.}, {22., 1.}, "RoundingRadius" -> 0]},
        ImageSizeCache->{{21.125000000000057`, 40.56665927240468}, {
         116.80243621812451`, 118.7277674447988}}],
       StatusArea[#, 1.]& ,
       TagBoxNote->"1."],
      StyleBox["1.`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[1., {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            GrayLevel[0.5], 
            AbsoluteThickness[1.5], 
            Opacity[0.66]}], {}, {}], 
         RectangleBox[{22., 0.}, {24., 8.}, "RoundingRadius" -> 0]},
        ImageSizeCache->{{39.31665927240468, 58.75831854480927}, {
         112.07511763140447`, 118.7277674447988}}],
       StatusArea[#, 8.]& ,
       TagBoxNote->"8."],
      StyleBox["8.`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[8., {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            GrayLevel[0.5], 
            AbsoluteThickness[1.5], 
            Opacity[0.66]}], {}, {}], 
         RectangleBox[{24., 0.}, {26., 21.}, "RoundingRadius" -> 0]},
        ImageSizeCache->{{57.50831854480927, 76.94997781721389}, {
         103.29581168463866`, 118.7277674447988}}],
       StatusArea[#, 21.]& ,
       TagBoxNote->"21."],
      StyleBox["21.`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[21., {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            GrayLevel[0.5], 
            AbsoluteThickness[1.5], 
            Opacity[0.66]}], {}, {}], 
         RectangleBox[{26., 0.}, {28., 36.}, "RoundingRadius" -> 0]},
        ImageSizeCache->{{75.69997781721389, 95.14163708961851}, {
         93.1658432845243, 118.7277674447988}}],
       StatusArea[#, 36.]& ,
       TagBoxNote->"36."],
      StyleBox["36.`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[36., {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            GrayLevel[0.5], 
            AbsoluteThickness[1.5], 
            Opacity[0.66]}], {}, {}], 
         RectangleBox[{28., 0.}, {30., 71.}, "RoundingRadius" -> 0]},
        ImageSizeCache->{{93.89163708961851, 113.33329636202316`}, {
         69.52925035092407, 118.7277674447988}}],
       StatusArea[#, 71.]& ,
       TagBoxNote->"71."],
      StyleBox["71.`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[71., {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            GrayLevel[0.5], 
            AbsoluteThickness[1.5], 
            Opacity[0.66]}], {}, {}], 
         RectangleBox[{30., 0.}, {32., 94.}, "RoundingRadius" -> 0]},
        ImageSizeCache->{{112.08329636202316`, 131.52495563442776`}, {
         53.99663213741536, 118.7277674447988}}],
       StatusArea[#, 94.]& ,
       TagBoxNote->"94."],
      StyleBox["94.`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[94., {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            GrayLevel[0.5], 
            AbsoluteThickness[1.5], 
            Opacity[0.66]}], {}, {}], 
         RectangleBox[{32., 0.}, {34., 81.}, "RoundingRadius" -> 0]},
        ImageSizeCache->{{130.27495563442776`, 149.71661490683235`}, {
         62.775938084181156`, 118.7277674447988}}],
       StatusArea[#, 81.]& ,
       TagBoxNote->"81."],
      StyleBox["81.`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[81., {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            GrayLevel[0.5], 
            AbsoluteThickness[1.5], 
            Opacity[0.66]}], {}, {}], 
         RectangleBox[{34., 0.}, {36., 78.}, "RoundingRadius" -> 0]},
        ImageSizeCache->{{148.46661490683235`, 167.908274179237}, {
         64.80193176420403, 118.7277674447988}}],
       StatusArea[#, 78.]& ,
       TagBoxNote->"78."],
      StyleBox["78.`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[78., {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            GrayLevel[0.5], 
            AbsoluteThickness[1.5], 
            Opacity[0.66]}], {}, {}], 
         RectangleBox[{36., 0.}, {38., 93.}, "RoundingRadius" -> 0]},
        ImageSizeCache->{{166.658274179237, 186.0999334516416}, {
         54.67196336408965, 118.7277674447988}}],
       StatusArea[#, 93.]& ,
       TagBoxNote->"93."],
      StyleBox["93.`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[93., {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            GrayLevel[0.5], 
            AbsoluteThickness[1.5], 
            Opacity[0.66]}], {}, {}], 
         RectangleBox[{38., 0.}, {40., 128.}, "RoundingRadius" -> 0]},
        ImageSizeCache->{{184.8499334516416, 204.29159272404624`}, {
         31.035370430489436`, 118.7277674447988}}],
       StatusArea[#, 128.]& ,
       TagBoxNote->"128."],
      StyleBox["128.`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[128., {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            GrayLevel[0.5], 
            AbsoluteThickness[1.5], 
            Opacity[0.66]}], {}, {}], 
         RectangleBox[{40., 0.}, {42., 179.}, "RoundingRadius" -> 0]},
        ImageSizeCache->{{203.04159272404624`, 
         222.48325199645083`}, {-3.4065221298994572`, 118.7277674447988}}],
       StatusArea[#, 179.]& ,
       TagBoxNote->"179."],
      StyleBox["179.`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[179., {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            GrayLevel[0.5], 
            AbsoluteThickness[1.5], 
            Opacity[0.66]}], {}, {}], 
         RectangleBox[{42., 0.}, {44., 207.}, "RoundingRadius" -> 0]},
        ImageSizeCache->{{221.23325199645083`, 
         240.67491126885548`}, {-22.315796476779624`, 118.7277674447988}}],
       StatusArea[#, 207.]& ,
       TagBoxNote->"207."],
      StyleBox["207.`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[207., {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            GrayLevel[0.5], 
            AbsoluteThickness[1.5], 
            Opacity[0.66]}], {}, {}], 
         RectangleBox[{44., 0.}, {46., 241.}, "RoundingRadius" -> 0]},
        ImageSizeCache->{{239.42491126885548`, 
         258.8665705412601}, {-45.27705818370556, 118.7277674447988}}],
       StatusArea[#, 241.]& ,
       TagBoxNote->"241."],
      StyleBox["241.`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[241., {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            GrayLevel[0.5], 
            AbsoluteThickness[1.5], 
            Opacity[0.66]}], {}, {}], 
         RectangleBox[{46., 0.}, {48., 309.}, "RoundingRadius" -> 0]},
        ImageSizeCache->{{257.6165705412601, 
         277.05822981366464`}, {-91.19958159755741, 118.7277674447988}}],
       StatusArea[#, 309.]& ,
       TagBoxNote->"309."],
      StyleBox["309.`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[309., {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            GrayLevel[0.5], 
            AbsoluteThickness[1.5], 
            Opacity[0.66]}], {}, {}], 
         RectangleBox[{48., 0.}, {50., 322.}, "RoundingRadius" -> 0]},
        ImageSizeCache->{{275.80822981366464`, 
         295.2498890860693}, {-99.9788875443232, 118.7277674447988}}],
       StatusArea[#, 322.]& ,
       TagBoxNote->"322."],
      StyleBox["322.`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[322., {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            GrayLevel[0.5], 
            AbsoluteThickness[1.5], 
            Opacity[0.66]}], {}, {}], 
         RectangleBox[{50., 0.}, {52., 351.}, "RoundingRadius" -> 0]},
        ImageSizeCache->{{293.9998890860693, 
         313.44154835847394`}, {-119.56349311787766`, 118.7277674447988}}],
       StatusArea[#, 351.]& ,
       TagBoxNote->"351."],
      StyleBox["351.`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[351., {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            GrayLevel[0.5], 
            AbsoluteThickness[1.5], 
            Opacity[0.66]}], {}, {}], 
         RectangleBox[{52., 0.}, {54., 314.}, "RoundingRadius" -> 0]},
        ImageSizeCache->{{312.19154835847394`, 
         331.6332076308786}, {-94.57623773092887, 118.7277674447988}}],
       StatusArea[#, 314.]& ,
       TagBoxNote->"314."],
      StyleBox["314.`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[314., {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            GrayLevel[0.5], 
            AbsoluteThickness[1.5], 
            Opacity[0.66]}], {}, {}], 
         RectangleBox[{54., 0.}, {56., 239.}, "RoundingRadius" -> 0]},
        ImageSizeCache->{{330.3832076308786, 
         349.8248669032831}, {-43.92639573035696, 118.7277674447988}}],
       StatusArea[#, 239.]& ,
       TagBoxNote->"239."],
      StyleBox["239.`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[239., {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            GrayLevel[0.5], 
            AbsoluteThickness[1.5], 
            Opacity[0.66]}], {}, {}], 
         RectangleBox[{56., 0.}, {58., 242.}, "RoundingRadius" -> 0]},
        ImageSizeCache->{{348.5748669032831, 
         368.0165261756878}, {-45.95238941037984, 118.7277674447988}}],
       StatusArea[#, 242.]& ,
       TagBoxNote->"242."],
      StyleBox["242.`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[242., {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            GrayLevel[0.5], 
            AbsoluteThickness[1.5], 
            Opacity[0.66]}], {}, {}], 
         RectangleBox[{58., 0.}, {60., 181.}, "RoundingRadius" -> 0]},
        ImageSizeCache->{{366.7665261756878, 
         386.2081854480924}, {-4.7571845832480335`, 118.7277674447988}}],
       StatusArea[#, 181.]& ,
       TagBoxNote->"181."],
      StyleBox["181.`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[181., {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            GrayLevel[0.5], 
            AbsoluteThickness[1.5], 
            Opacity[0.66]}], {}, {}], 
         RectangleBox[{60., 0.}, {62., 92.}, "RoundingRadius" -> 0]},
        ImageSizeCache->{{384.9581854480924, 404.39984472049696`}, {
         55.347294590763944`, 118.7277674447988}}],
       StatusArea[#, 92.]& ,
       TagBoxNote->"92."],
      StyleBox["92.`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[92., {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            GrayLevel[0.5], 
            AbsoluteThickness[1.5], 
            Opacity[0.66]}], {}, {}], 
         RectangleBox[{62., 0.}, {64., 54.}, "RoundingRadius" -> 0]},
        ImageSizeCache->{{403.14984472049696`, 422.5915039929016}, {
         81.00988120438703, 118.7277674447988}}],
       StatusArea[#, 54.]& ,
       TagBoxNote->"54."],
      StyleBox["54.`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[54., {
        GrayLevel[0]}], "Tooltip"]& ], 
    TagBox[
     TooltipBox[
      TagBox[
       DynamicBox[{
         FEPrivate`If[
          CurrentValue["MouseOver"], 
          EdgeForm[{
            GrayLevel[0.5], 
            AbsoluteThickness[1.5], 
            Opacity[0.66]}], {}, {}], 
         RectangleBox[{64., 0.}, {66., 12.}, "RoundingRadius" -> 0]},
        ImageSizeCache->{{421.3415039929016, 440.78316326530626`}, {
         109.3737927247073, 118.7277674447988}}],
       StatusArea[#, 12.]& ,
       TagBoxNote->"12."],
      StyleBox["12.`", {
        GrayLevel[0]}, StripOnInput -> False]],
     Annotation[#, 
      Style[12., {
        GrayLevel[0]}], "Tooltip"]& ]}, {}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesOrigin->{20., 0.},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  PlotRange->{{20, 66}, {All, All}},
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.1]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.507035813916745*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Importing only parts of one particular branch.\
\>", "Subsubsection",
 CellChangeTimes->{{3.498483889952964*^9, 3.498483925567772*^9}, {
  3.498483956474862*^9, 3.498483959168501*^9}, {3.4984846990172873`*^9, 
  3.4984847009928627`*^9}, {3.498493103795794*^9, 3.498493110273582*^9}, {
  3.5008288737913947`*^9, 3.500828924571995*^9}, {3.5008289592121763`*^9, 
  3.5008290190707855`*^9}, {3.500829511538404*^9, 3.5008295135227027`*^9}, {
  3.502723513447506*^9, 3.5027235138381987`*^9}, {3.506349803628007*^9, 
  3.5063498049403973`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"dat", "=", 
  RowBox[{"Import", "[", 
   RowBox[{"\"\<cernstaff.root\>\"", ",", " ", 
    RowBox[{"{", 
     RowBox[{
     "\"\<ROOT\>\"", ",", " ", "\"\<TTreeData\>\"", ",", " ", "\"\<T\>\"", 
      ",", " ", "\"\<Age\>\""}], "}"}], ",", " ", 
    RowBox[{"\"\<Range\>\"", " ", "\[Rule]", " ", 
     RowBox[{"{", 
      RowBox[{"11", ",", " ", "20"}], "}"}]}]}], "]"}]}]], "Input",
 CellFrame->{{0, 0}, {0, 0.5}},
 CellChangeTimes->{{3.498484262143279*^9, 3.498484294879013*^9}, {
   3.498490652197131*^9, 3.4984906525961943`*^9}, {3.498490786930372*^9, 
   3.498490795515463*^9}, 3.498496231941674*^9, {3.498496524980996*^9, 
   3.498496525560548*^9}, 3.49849671915097*^9, {3.4984967683226023`*^9, 
   3.4984967712906017`*^9}, {3.5008241805268826`*^9, 3.500824205980822*^9}, {
   3.5008242812488556`*^9, 3.5008242883740835`*^9}, {3.500824329109762*^9, 
   3.5008243319536033`*^9}, {3.500824529031797*^9, 3.500824529766158*^9}, {
   3.5008245986867094`*^9, 3.5008245999835596`*^9}, {3.5008250964640613`*^9, 
   3.500825099885783*^9}, {3.5008288082141094`*^9, 3.5008288165421276`*^9}, {
   3.5008290308518844`*^9, 3.5008290389767804`*^9}, {3.502723538451826*^9, 
   3.5027235742548866`*^9}, {3.506349903791548*^9, 3.5063499182122226`*^9}, {
   3.5085887397498846`*^9, 3.508588739968587*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Partial branch import with bounds: \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"11", ",", "20"}], "}"}]}],
  SequenceForm["Partial branch import with bounds: ", {11, 20}],
  Editable->False]], "Print",
 CellChangeTimes->{3.5070358140886126`*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "51", ",", "54", ",", "54", ",", "46", ",", "54", ",", "57", ",", "55", ",",
    "55", ",", "57", ",", "51"}], "}"}]], "Output",
 CellChangeTimes->{
  3.5008288311200657`*^9, {3.5008290359299445`*^9, 3.500829039336151*^9}, 
   3.5008294137921576`*^9, 3.5010130823700156`*^9, 3.5016184347006865`*^9, {
   3.502723564659479*^9, 3.502723574692462*^9}, 3.503235633119337*^9, 
   3.503235664702774*^9, 3.5063498154707713`*^9, {3.5063499130876493`*^9, 
   3.50634991866531*^9}, 3.5063504103399453`*^9, 3.5070358141198606`*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Importing all branches of a TTree.\
\>", "Subsubsection",
 CellChangeTimes->{{3.498483889952964*^9, 3.498483925567772*^9}, {
  3.498483956474862*^9, 3.498483959168501*^9}, {3.4984846990172873`*^9, 
  3.4984847009928627`*^9}, {3.498493103795794*^9, 3.498493110273582*^9}, {
  3.5008288737913947`*^9, 3.500828924571995*^9}, {3.5008289592121763`*^9, 
  3.5008289675089455`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "This", " ", "imports", " ", "the", " ", "metadata", " ", "and", " ", 
    "the", " ", "data", " ", "a", " ", "given", " ", "NTuple"}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Import", "[", 
    RowBox[{"\"\<basic.root\>\"", ",", " ", 
     RowBox[{"{", 
      RowBox[{
      "\"\<ROOT\>\"", ",", " ", "\"\<TTreeMetadata\>\"", ",", " ", 
       "\"\<ntuple\>\""}], "}"}]}], "]"}], "\[IndentingNewLine]", 
   RowBox[{"Import", "[", 
    RowBox[{"\"\<basic.root\>\"", ",", " ", 
     RowBox[{"{", 
      RowBox[{
      "\"\<ROOT\>\"", ",", " ", "\"\<TTreeData\>\"", ",", " ", 
       "\"\<ntuple\>\""}], "}"}]}], "]"}]}]}]], "Input",
 CellFrame->{{0, 0}, {0, 0.5}},
 CellChangeTimes->{{3.498484126665839*^9, 3.498484166433033*^9}, {
   3.4984845171400967`*^9, 3.498484517445868*^9}, {3.498484662021961*^9, 
   3.498484674276703*^9}, {3.498490503553673*^9, 3.498490506542944*^9}, 
   3.498496298032745*^9, {3.498499443423614*^9, 3.498499448203699*^9}, {
   3.498931363865445*^9, 3.498931392790547*^9}, 3.5000536457092247`*^9, {
   3.500655064494585*^9, 3.50065506516634*^9}, {3.500826523473114*^9, 
   3.500826596313134*^9}, {3.50082893435312*^9, 3.5008289413061557`*^9}, {
   3.5008291448493605`*^9, 3.500829150817881*^9}, {3.506349927539572*^9, 
   3.5063499299143744`*^9}, {3.508588767978116*^9, 3.508588768259305*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"\<\"x\"\>", ",", "\<\"x\"\>", ",", "\<\"Float_t\"\>", ",", "4"}],
     "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"y\"\>", ",", "\<\"y\"\>", ",", "\<\"Float_t\"\>", ",", "4"}],
     "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"z\"\>", ",", "\<\"z\"\>", ",", "\<\"Float_t\"\>", ",", "4"}],
     "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.5006550656974945`*^9, 3.5006561987363005`*^9, 3.5008242245595417`*^9, 
   3.500824515516432*^9, {3.5008246116552105`*^9, 3.5008246295767417`*^9}, {
   3.5008265239730883`*^9, 3.5008265522841387`*^9}, 3.5008289420248966`*^9, 
   3.500829400402047*^9, 3.501013081143106*^9, 3.501618417748743*^9, 
   3.503235633556694*^9, 3.506349930836172*^9, 3.506349978285349*^9, 
   3.5063504104805727`*^9, 3.507035814338601*^9}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "1.`"}], ",", "1.`", ",", "2.`", ",", "3.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2.`", ",", "5.`", ",", "5.`", ",", "3.4000000953674316`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3.`", ",", "6.`", ",", "45.`", ",", "4.`"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.5006550656974945`*^9, 3.5006561987363005`*^9, 3.5008242245595417`*^9, 
   3.500824515516432*^9, {3.5008246116552105`*^9, 3.5008246295767417`*^9}, {
   3.5008265239730883`*^9, 3.5008265522841387`*^9}, 3.5008289420248966`*^9, 
   3.500829400402047*^9, 3.501013081143106*^9, 3.501618417748743*^9, 
   3.503235633556694*^9, 3.506349930836172*^9, 3.506349978285349*^9, 
   3.5063504104805727`*^9, 3.5070358144010983`*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Importing only certain parts of all branch of a TTree.\
\>", "Subsubsection",
 CellChangeTimes->{{3.498483889952964*^9, 3.498483925567772*^9}, {
  3.498483956474862*^9, 3.498483959168501*^9}, {3.4984846990172873`*^9, 
  3.4984847009928627`*^9}, {3.498493103795794*^9, 3.498493110273582*^9}, {
  3.5008288737913947`*^9, 3.500828924571995*^9}, {3.5008289592121763`*^9, 
  3.5008289675089455`*^9}, {3.5008290768512955`*^9, 3.5008290916948557`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "We", " ", "need", " ", "to", " ", "use", " ", "the", " ", "\"\<Range\>\"",
     " ", "option"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"Import", "[", 
   RowBox[{"\"\<basic.root\>\"", ",", " ", 
    RowBox[{"{", 
     RowBox[{
     "\"\<ROOT\>\"", ",", " ", "\"\<TTreeData\>\"", ",", " ", 
      "\"\<ntuple\>\""}], "}"}], ",", " ", 
    RowBox[{"\"\<Range\>\"", " ", "\[Rule]", " ", 
     RowBox[{"{", 
      RowBox[{"2", ",", "4"}], "}"}]}]}], "]"}]}]], "Input",
 CellFrame->{{0, 0}, {0, 0.5}},
 CellChangeTimes->{{3.498484262143279*^9, 3.498484294879013*^9}, {
   3.498490652197131*^9, 3.4984906525961943`*^9}, {3.498490786930372*^9, 
   3.498490795515463*^9}, 3.498496231941674*^9, {3.498496524980996*^9, 
   3.498496525560548*^9}, 3.49849671915097*^9, {3.4984967683226023`*^9, 
   3.4984967712906017`*^9}, {3.500826625592885*^9, 3.500826645232505*^9}, {
   3.5008291080070252`*^9, 3.5008291304280396`*^9}, {3.5063499974868765`*^9, 
   3.506350004126949*^9}, {3.5085887727583256`*^9, 3.5085887729926496`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1.`", ",", "2.`", ",", "3.5`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5.`", ",", "5.`", ",", "3.4000000953674316`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"6.`", ",", "45.`", ",", "4.`"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.5008291314123764`*^9, {3.5008294036675463`*^9, 3.5008294076673927`*^9}, 
   3.5010130812828803`*^9, 3.5016184225297465`*^9, 3.5032356336347933`*^9, {
   3.5063499942683945`*^9, 3.506350004798768*^9}, 3.5063504106212006`*^9, 
   3.5070358145417175`*^9}]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["One more example", "Subsubsection",
 CellChangeTimes->{{3.498483889952964*^9, 3.498483925567772*^9}, {
  3.498483956474862*^9, 3.498483959168501*^9}, {3.4984846990172873`*^9, 
  3.4984847009928627`*^9}, {3.498493103795794*^9, 3.498493110273582*^9}, {
  3.5008288737913947`*^9, 3.500828924571995*^9}, {3.5008289592121763`*^9, 
  3.5008290190707855`*^9}, {3.500829058757777*^9, 3.5008290606796274`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "import", " ", "only", " ", "the", " ", "11", "th", " ", "through", " ", 
    "25", "th", " ", "entries", " ", "across", " ", "all", " ", "branches"}], 
   " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"alldata", "=", 
    RowBox[{"Import", "[", 
     RowBox[{"\"\<cernstaff.root\>\"", ",", " ", 
      RowBox[{"{", 
       RowBox[{
       "\"\<ROOT\>\"", ",", " ", "\"\<TTreeData\>\"", ",", " ", "\"\<T\>\""}],
        "}"}], ",", " ", 
      RowBox[{"\"\<Range\>\"", " ", "\[Rule]", " ", 
       RowBox[{"{", 
        RowBox[{"11", ",", "25"}], "}"}]}]}], "]"}]}], ";"}]}]], "Input",
 CellChangeTimes->{{3.498484320795517*^9, 3.498484346978204*^9}, 
   3.4984968214220963`*^9, {3.5008291673641205`*^9, 3.500829235767744*^9}, {
   3.5014308675913677`*^9, 3.5014308750595913`*^9}, 3.50161844540299*^9, 
   3.5063500128918447`*^9, {3.507036146917726*^9, 3.50703618802789*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"present", " ", "the", " ", "data", " ", 
    RowBox[{"visually", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"header", " ", "=", " ", 
     RowBox[{"First", "/@", 
      RowBox[{"Import", "[", 
       RowBox[{"\"\<cernstaff.root\>\"", ",", " ", 
        RowBox[{"{", 
         RowBox[{
         "\"\<ROOT\>\"", ",", " ", "\"\<TTreeMetadata\>\"", ",", " ", 
          "\"\<T\>\""}], "}"}]}], "]"}]}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"Grid", "[", 
    RowBox[{
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"{", "header", "}"}], ",", " ", 
       RowBox[{"Transpose", "[", "alldata", "]"}]}], "]"}], ",", " ", 
     RowBox[{"Frame", "\[Rule]", "All"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.4984843501829557`*^9, 3.4984844680536423`*^9}, {
   3.4984865853139467`*^9, 3.498486585748279*^9}, 3.498496823804883*^9, {
   3.4984994777064943`*^9, 3.498499482599349*^9}, {3.5008292553919907`*^9, 
   3.5008292753131003`*^9}, 3.5063500247814803`*^9, {3.507036208903291*^9, 
   3.507036213747134*^9}}],

Cell[BoxData[
 TagBox[GridBox[{
    {"\<\"Category\"\>", "\<\"Flag\"\>", "\<\"Age\"\>", "\<\"Service\"\>", \
"\<\"Children\"\>", "\<\"Grade\"\>", "\<\"Step\"\>", "\<\"Hrweek\"\>", \
"\<\"Cost\"\>", "\<\"Division\"\>", "\<\"Nation\"\>"},
    {"361", "15", "51", "29", "0", "7", "13", "40", 
     "7599", "\<\"PS\"\>", "\<\"FR\"\>"},
    {"303", "15", "54", "31", "2", "8", "13", "40", 
     "9315", "\<\"PS\"\>", "\<\"CH\"\>"},
    {"302", "15", "54", "29", "0", "7", "13", "40", 
     "7599", "\<\"PS\"\>", "\<\"CH\"\>"},
    {"300", "15", "46", "25", "0", "8", "6", "40", 
     "7892", "\<\"PS\"\>", "\<\"CH\"\>"},
    {"361", "15", "54", "26", "1", "7", "13", "40", 
     "7850", "\<\"PS\"\>", "\<\"DE\"\>"},
    {"361", "15", "57", "29", "0", "7", "13", "40", 
     "7599", "\<\"PS\"\>", "\<\"FR\"\>"},
    {"316", "11", "55", "28", "0", "8", "11", "40", 
     "8137", "\<\"PS\"\>", "\<\"CH\"\>"},
    {"303", "15", "55", "26", "1", "7", "13", "40", 
     "7850", "\<\"SPS\"\>", "\<\"FR\"\>"},
    {"361", "15", "57", "29", "1", "7", "8", "40", 
     "7294", "\<\"PS\"\>", "\<\"FR\"\>"},
    {"361", "15", "51", "28", "2", "7", "13", "40", 
     "8101", "\<\"PS\"\>", "\<\"FR\"\>"},
    {"419", "13", "54", "29", "0", "5", "13", "40", 
     "5720", "\<\"PS\"\>", "\<\"FR\"\>"},
    {"202", "15", "57", "26", "1", "12", "13", "40", 
     "15832", "\<\"PS\"\>", "\<\"DE\"\>"},
    {"304", "15", "63", "29", "1", "10", "13", "40", 
     "12226", "\<\"PS\"\>", "\<\"NL\"\>"},
    {"204", "15", "56", "27", "0", "11", "9", "40", 
     "13135", "\<\"PS\"\>", "\<\"DE\"\>"},
    {"204", "15", "49", "27", "0", "9", "9", "40", 
     "9617", "\<\"LEP\"\>", "\<\"GB\"\>"}
   },
   AutoDelete->False,
   GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
  "Grid"]], "Output",
 CellChangeTimes->{
  3.506350411058709*^9, 3.5070358147135844`*^9, {3.507036240763278*^9, 
   3.5070362476696606`*^9}}]
}, Open  ]],

Cell[TextData[{
 "Note that the results of \n  Import[ file, {\[OpenCurlyDoubleQuote]ROOT\
\[CloseCurlyDoubleQuote], \[OpenCurlyDoubleQuote]TreeData\
\[CloseCurlyDoubleQuote], ",
 StyleBox["tree",
  FontSlant->"Italic"],
 "} ]\nis of the form \n  {\n    {px1, px2, px3, ...}, //branch px\n    {py1, \
py2, py3, ...}, //branch py\n    ...\n  }.\nTo get the first \
\[OpenCurlyDoubleQuote]event\[CloseCurlyDoubleQuote], we would have to \
Transpose[] the result.\nWe can easily pick out subportions of the data using \
the Part[] command of ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "."
}], "Text",
 CellChangeTimes->{{3.495468497648314*^9, 3.495468500528111*^9}, {
  3.495468563465575*^9, 3.495468647615963*^9}, {3.495468706668795*^9, 
  3.495468844049102*^9}, {3.498483935097855*^9, 3.498483937281838*^9}, {
  3.4984839819621143`*^9, 3.498484083096613*^9}, {3.4984847206013823`*^9, 
  3.498484782440452*^9}, {3.4984860984565077`*^9, 3.49848625229305*^9}},
 FontFamily->"Courier [ibm]",
 FontSize->10]
}, Closed]],

Cell[CellGroupData[{

Cell["Error handling", "Subsubsection",
 CellChangeTimes->{{3.498483889952964*^9, 3.498483925567772*^9}, {
   3.498483956474862*^9, 3.498483959168501*^9}, {3.4984846990172873`*^9, 
   3.4984847009928627`*^9}, {3.498493103795794*^9, 3.498493110273582*^9}, {
   3.5008288737913947`*^9, 3.500828876619484*^9}, 3.5008294468690124`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "When", " ", "the", " ", "Tree", " ", "is", " ", "not", " ", "present"}], 
    ",", " ", 
    RowBox[{"we", " ", "exit", " ", "safely", " ", "and", " ", "return", " ", 
     RowBox[{"$Failed", "."}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"Import", "[", 
   RowBox[{"\"\<cernstaff.root\>\"", ",", " ", 
    RowBox[{"{", 
     RowBox[{
     "\"\<ROOT\>\"", ",", " ", "\"\<TTreeMetadata\>\"", ",", " ", 
      "\"\<Invalid_Tree\>\""}], "}"}]}], "]"}]}]], "Input",
 CellFrame->{{0, 0}, {0, 0.5}},
 CellChangeTimes->{{3.498484180783737*^9, 3.498484227964623*^9}, 
   3.4984962291617413`*^9, {3.498499455801323*^9, 3.4984994599796143`*^9}, {
   3.506350081168377*^9, 3.506350090949126*^9}, {3.508588786505334*^9, 
   3.508588786911495*^9}}],

Cell[BoxData["\<\"No such TTree exists\"\>"], "Print",
 CellChangeTimes->{3.5063500924021764`*^9, 3.506350411402466*^9, 
  3.507035814854203*^9}],

Cell[BoxData["$Failed"], "Output",
 CellChangeTimes->{
  3.4984842283477163`*^9, 3.498486573071269*^9, 3.498490551578618*^9, 
   3.498490706545248*^9, 3.498490783842613*^9, 3.498496229574417*^9, 
   3.4984963026639767`*^9, 3.498496476556116*^9, 3.4984965209113827`*^9, 
   3.498496555985692*^9, 3.498496699217349*^9, {3.49849674327494*^9, 
   3.4984967613927937`*^9}, 3.498499460407442*^9, 3.4988444558724833`*^9, 
   3.49892475671875*^9, 3.4989257316882877`*^9, 3.500053677927562*^9, 
   3.5006550691500006`*^9, 3.5006561987987995`*^9, 3.5008242259345856`*^9, 
   3.5008245165632863`*^9, {3.500824613717671*^9, 3.500824630857967*^9}, 
   3.500829438838071*^9, 3.5010130827738085`*^9, 3.501618460073738*^9, 
   3.503235634056531*^9, 3.5063500924021764`*^9, 3.506350411402466*^9, 
   3.507035814854203*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "When", " ", "a", " ", "branch", " ", "is", " ", "not", " ", "present"}], 
    ",", " ", 
    RowBox[{"we", " ", "exit", " ", "safely", " ", "and", " ", "return", " ", 
     RowBox[{"$Failed", "."}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"Import", "[", 
   RowBox[{"\"\<cernstaff.root\>\"", ",", " ", 
    RowBox[{"{", 
     RowBox[{
     "\"\<ROOT\>\"", ",", " ", "\"\<TTreeData\>\"", ",", " ", "\"\<T\>\"", 
      ",", " ", "\"\<InvalidBranch\>\""}], "}"}]}], "]"}]}]], "Input",
 CellFrame->{{0, 0}, {0, 0.5}},
 CellChangeTimes->{{3.4984844916192617`*^9, 3.498484504739067*^9}, 
   3.498496577479594*^9, 3.500826655856961*^9, 3.5063500995893087`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Allowed TBranches are: \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"\<\"Category\"\>", ",", "\<\"Flag\"\>", ",", "\<\"Age\"\>", 
     ",", "\<\"Service\"\>", ",", "\<\"Children\"\>", ",", "\<\"Grade\"\>", 
     ",", "\<\"Step\"\>", ",", "\<\"Hrweek\"\>", ",", "\<\"Cost\"\>", 
     ",", "\<\"Division\"\>", ",", "\<\"Nation\"\>"}], "}"}], 
   "\[InvisibleSpace]", "\<\" and \"\>", 
   "\[InvisibleSpace]", "\<\"InvalidBranch\"\>", 
   "\[InvisibleSpace]", "\<\" is invalid.\"\>"}],
  SequenceForm[
  "Allowed TBranches are: ", {
   "Category", "Flag", "Age", "Service", "Children", "Grade", "Step", 
    "Hrweek", "Cost", "Division", "Nation"}, " and ", "InvalidBranch", 
   " is invalid."],
  Editable->False]], "Print",
 CellChangeTimes->{3.506350100136155*^9, 3.506350412168105*^9, 
  3.5070358149479485`*^9}],

Cell[BoxData["$Failed"], "Output",
 CellChangeTimes->{3.500655074274082*^9, 3.5006561992987933`*^9, 
  3.500824230872244*^9, 3.500824521781936*^9, 3.500824632811054*^9, 
  3.5008266613098063`*^9, 3.500827903183719*^9, 3.5008287639160385`*^9, 
  3.500829441728585*^9, 3.5010130828359303`*^9, 3.501618460151857*^9, 
  3.50323563418149*^9, 3.506350100136155*^9, 3.506350412168105*^9, 
  3.5070358149479485`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "When", " ", "the", " ", "bounds", " ", "are", " ", "not", " ", 
     "appropriate"}], ",", " ", 
    RowBox[{"we", " ", "exit", " ", "safely", " ", "and", " ", "return", " ", 
     RowBox[{"$Failed", "."}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"Import", "[", 
   RowBox[{"\"\<cernstaff.root\>\"", ",", " ", 
    RowBox[{"{", 
     RowBox[{
     "\"\<ROOT\>\"", ",", " ", "\"\<TTreeData\>\"", ",", " ", "\"\<T\>\"", 
      ",", " ", "\"\<Age\>\""}], "}"}], ",", " ", 
    RowBox[{"\"\<Range\>\"", " ", "\[Rule]", " ", 
     RowBox[{"{", 
      RowBox[{"5", ",", " ", "50000000"}], "}"}]}]}], "]"}]}]], "Input",
 CellFrame->{{0, 0}, {0, 0.5}},
 CellChangeTimes->{{3.4984844916192617`*^9, 3.498484504739067*^9}, 
   3.498496577479594*^9, 3.500826655856961*^9, {3.5008294588685513`*^9, 
   3.500829475914772*^9}, 3.506350106745192*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Partial branch import with bounds: \"\>", "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"5", ",", "50000000"}], "}"}]}],
  SequenceForm["Partial branch import with bounds: ", {5, 50000000}],
  Editable->False]], "Print",
 CellChangeTimes->{3.5063501070576763`*^9, 3.5063504125587378`*^9, 
  3.5070358150885677`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Bound not accessible; the branch \"\>", 
   "\[InvisibleSpace]", "\<\"Age\"\>", 
   "\[InvisibleSpace]", "\<\" has only \"\>", "\[InvisibleSpace]", "3354", 
   "\[InvisibleSpace]", "\<\" entires.\"\>"}],
  SequenceForm[
  "Bound not accessible; the branch ", "Age", " has only ", 3354, " entires."],
  Editable->False]], "Print",
 CellChangeTimes->{3.5063501070576763`*^9, 3.5063504125587378`*^9, 
  3.507035815104192*^9}]
}, Open  ]],

Cell[BoxData["$Failed"], "Output",
 CellChangeTimes->{3.500829476430377*^9, 3.501013082913583*^9, 
  3.501618460214352*^9, 3.5032356342283497`*^9, 3.5063501070733004`*^9, 
  3.5063504125587378`*^9, 3.5070358151198163`*^9}]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Interface with TH1F Object", "Subsection",
 CellChangeTimes->{{3.498483889952964*^9, 3.498483925567772*^9}, {
   3.498483956474862*^9, 3.498483959168501*^9}, {3.4984846990172873`*^9, 
   3.4984847009928627`*^9}, {3.498493103795794*^9, 3.498493110273582*^9}, 
   3.500829520553683*^9}],

Cell[TextData[{
 "The wrappers to access TH1F functionalities have the forms:\n",
 StyleBox["  Import[ ",
  FontFamily->"Courier New"],
 StyleBox["file",
  FontFamily->"Courier New",
  FontSlant->"Italic"],
 StyleBox[", {\[OpenCurlyDoubleQuote]ROOT\[CloseCurlyDoubleQuote], \
\[OpenCurlyDoubleQuote]TH1FData\[CloseCurlyDoubleQuote], ",
  FontFamily->"Courier New"],
 StyleBox["hist",
  FontFamily->"Courier New",
  FontSlant->"Italic"],
 StyleBox["} ],\n  Import[ ",
  FontFamily->"Courier New"],
 StyleBox["file",
  FontFamily->"Courier New",
  FontSlant->"Italic"],
 StyleBox[", {\[OpenCurlyDoubleQuote]ROOT\[CloseCurlyDoubleQuote], \
\[OpenCurlyDoubleQuote]TH1FGraphics\[CloseCurlyDoubleQuote], ",
  FontFamily->"Courier New"],
 StyleBox["hist",
  FontFamily->"Courier New",
  FontSlant->"Italic"],
 StyleBox["} ]",
  FontFamily->"Courier New"],
 "\nwhere:\n    ",
 StyleBox["hist ",
  FontSlant->"Italic"],
 " is the name of the TH1F object."
}], "Text",
 CellChangeTimes->{{3.495468497648314*^9, 3.495468500528111*^9}, {
   3.495468563465575*^9, 3.495468647615963*^9}, {3.495468706668795*^9, 
   3.495468844049102*^9}, {3.498483935097855*^9, 3.498483937281838*^9}, {
   3.4984839819621143`*^9, 3.498484083096613*^9}, {3.4984847206013823`*^9, 
   3.498484782440452*^9}, {3.498496219124737*^9, 3.498496220755698*^9}, {
   3.498499361837543*^9, 3.498499364531248*^9}, {3.4984993962509413`*^9, 
   3.498499434835371*^9}, {3.498844524513542*^9, 3.498844572298003*^9}, 
   3.502723298642826*^9},
 FontFamily->"Courier [ibm]",
 FontSize->10],

Cell[BoxData[
 RowBox[{
  RowBox[{"SetDirectory", "[", 
   RowBox[{"NotebookDirectory", "[", "]"}], "]"}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "This", " ", "imports", " ", "the", " ", "histogram", " ", "data", " ", 
    "of", " ", "a", " ", "given", " ", "TH1F", " ", 
    RowBox[{"object", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"histdata", "=", 
    RowBox[{"Import", "[", 
     RowBox[{"\"\<demo.root\>\"", ",", 
      RowBox[{"{", 
       RowBox[{"\"\<ROOT\>\"", ",", "\"\<TH1FData\>\"", ",", "\"\<h7\>\""}], 
       "}"}]}], "]"}]}], ";"}]}]], "Input",
 CellFrame->{{0, 0}, {0, 0.5}},
 CellChangeTimes->{{3.498484126665839*^9, 3.498484166433033*^9}, {
   3.4984845171400967`*^9, 3.498484517445868*^9}, {3.498484662021961*^9, 
   3.498484674276703*^9}, {3.498490503553673*^9, 3.498490506542944*^9}, 
   3.498496298032745*^9, {3.498499443423614*^9, 3.498499448203699*^9}, {
   3.4988445926497173`*^9, 3.498844654989193*^9}, {3.4989268963148975`*^9, 
   3.498926902330446*^9}, {3.5000537097865295`*^9, 3.5000537112083864`*^9}, {
   3.5006550928645*^9, 3.500655093208188*^9}, {3.5018694958752975`*^9, 
   3.5018694996564994`*^9}, {3.50254796208443*^9, 3.502547964600168*^9}, {
   3.5027228411043854`*^9, 3.502722854631565*^9}}],

Cell["\<\
The data is of the form:
  { {x1, \[CapitalDelta]x1, count1, error1}, {x2, \[CapitalDelta]x2, count2, \
error2}, ... }\
\>", "Text",
 CellChangeTimes->{{3.495468497648314*^9, 3.495468500528111*^9}, {
   3.495468563465575*^9, 3.495468647615963*^9}, {3.495468706668795*^9, 
   3.495468844049102*^9}, {3.498483935097855*^9, 3.498483937281838*^9}, {
   3.4984839819621143`*^9, 3.498484083096613*^9}, {3.4984847206013823`*^9, 
   3.498484782440452*^9}, {3.498496219124737*^9, 3.498496220755698*^9}, {
   3.498499361837543*^9, 3.498499364531248*^9}, {3.4984993962509413`*^9, 
   3.498499434835371*^9}, {3.498844524513542*^9, 3.498844572298003*^9}, {
   3.498844755939704*^9, 3.4988447752899303`*^9}, 3.5027231074847918`*^9},
 FontFamily->"Courier [ibm]",
 FontSize->10],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "show", " ", "first", " ", "10", " ", "entries", " ", "in", " ", "a", " ", 
    "grid"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"head", "=", 
     RowBox[{"{", 
      RowBox[{
      "\"\<x\>\"", ",", "\"\<\[CapitalDelta]x\>\"", ",", "\"\<count\>\"", 
       ",", "\"\<\[CapitalDelta]count\>\""}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Grid", "[", 
    RowBox[{
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"{", "head", "}"}], ",", 
       RowBox[{"Take", "[", 
        RowBox[{"histdata", ",", "10"}], "]"}]}], "]"}], ",", 
     RowBox[{"Frame", "\[Rule]", " ", "All"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.502722709362775*^9, 3.5027227714066067`*^9}, {
  3.502722876999835*^9, 3.5027228923702097`*^9}}],

Cell[BoxData[
 TagBox[GridBox[{
    {"\<\"x\"\>", "\<\"\[CapitalDelta]x\"\>", "\<\"count\"\>", "\<\"\
\[CapitalDelta]count\"\>"},
    {
     RowBox[{"-", "4.`"}], "0.08`", "0.`", "0.`"},
    {
     RowBox[{"-", "3.92`"}], "0.08`", "0.`", "0.`"},
    {
     RowBox[{"-", "3.84`"}], "0.08`", "0.`", "0.`"},
    {
     RowBox[{"-", "3.76`"}], "0.08`", "0.`", "0.`"},
    {
     RowBox[{"-", "3.68`"}], "0.08`", "0.`", "0.`"},
    {
     RowBox[{"-", "3.6`"}], "0.08`", "0.`", "0.`"},
    {
     RowBox[{"-", "3.52`"}], "0.08`", "0.`", "0.`"},
    {
     RowBox[{"-", "3.44`"}], "0.08`", "0.`", "0.`"},
    {
     RowBox[{"-", "3.36`"}], "0.08`", "1.`", "1.`"},
    {
     RowBox[{"-", "3.2800000000000002`"}], "0.08`", "0.`", "0.`"}
   },
   AutoDelete->False,
   GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
  "Grid"]], "Output",
 CellChangeTimes->{{3.5027228830448914`*^9, 3.502722892932541*^9}, 
   3.5063501179633675`*^9, 3.5063504126993656`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Import", " ", "the", " ", "histogram", " ", "directly", " ", "as", " ", 
    "a", " ", "Graphics"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"graphics1", "=", 
   RowBox[{"Import", "[", 
    RowBox[{"\"\<demo.root\>\"", ",", 
     RowBox[{"{", 
      RowBox[{
      "\"\<ROOT\>\"", ",", "\"\<TH1FGraphics\>\"", ",", "\"\<h10\>\""}], 
      "}"}]}], "]"}]}]}]], "Input",
 CellFrame->{{0, 0}, {0, 0.5}},
 CellChangeTimes->{{3.498484126665839*^9, 3.498484166433033*^9}, {
   3.4984845171400967`*^9, 3.498484517445868*^9}, {3.498484662021961*^9, 
   3.498484674276703*^9}, {3.498490503553673*^9, 3.498490506542944*^9}, 
   3.498496298032745*^9, {3.498499443423614*^9, 3.498499448203699*^9}, {
   3.4988445926497173`*^9, 3.498844654989193*^9}, {3.498844800056354*^9, 
   3.498844826445148*^9}, {3.5025481162007093`*^9, 3.502548150702255*^9}, {
   3.502722901148819*^9, 3.502722936138291*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Options", " ", "available", " ", "to", " ", 
    RowBox[{"Histogram", "[", "]"}], " ", "can", " ", "be", " ", "passed", 
    " ", 
    RowBox[{"directly", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"graphics2", "=", 
   RowBox[{"Import", "[", 
    RowBox[{"\"\<demo.root\>\"", ",", 
     RowBox[{"{", 
      RowBox[{
      "\"\<ROOT\>\"", ",", "\"\<TH1FGraphics\>\"", ",", "\"\<h7\>\""}], "}"}],
      ",", 
     RowBox[{"ColorFunction", "\[Rule]", 
      RowBox[{"Function", "[", 
       RowBox[{
        RowBox[{"{", "height", "}"}], ",", 
        RowBox[{
         RowBox[{"ColorData", "[", "\"\<Rainbow\>\"", "]"}], "[", "height", 
         "]"}]}], "]"}]}]}], "]"}]}]}]], "Input",
 CellFrame->{{0, 0}, {0, 0.5}},
 CellChangeTimes->{{3.498484126665839*^9, 3.498484166433033*^9}, {
   3.4984845171400967`*^9, 3.498484517445868*^9}, {3.498484662021961*^9, 
   3.498484674276703*^9}, {3.498490503553673*^9, 3.498490506542944*^9}, 
   3.498496298032745*^9, {3.498499443423614*^9, 3.498499448203699*^9}, {
   3.4988445926497173`*^9, 3.498844654989193*^9}, {3.498844800056354*^9, 
   3.498844826445148*^9}, {3.5025481162007093`*^9, 3.502548150702255*^9}, {
   3.502722901148819*^9, 3.502722954179737*^9}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Interface with TH2F Object", "Subsection",
 CellChangeTimes->{{3.498483889952964*^9, 3.498483925567772*^9}, {
   3.498483956474862*^9, 3.498483959168501*^9}, {3.4984846990172873`*^9, 
   3.4984847009928627`*^9}, {3.498493103795794*^9, 3.498493110273582*^9}, 
   3.500829520553683*^9, 3.502543644626873*^9}],

Cell[TextData[{
 "The wrappers to access TH1F functionalities have the forms:\n",
 StyleBox["  Import[ ",
  FontFamily->"Courier New"],
 StyleBox["file",
  FontFamily->"Courier New",
  FontSlant->"Italic"],
 StyleBox[", {\[OpenCurlyDoubleQuote]ROOT\[CloseCurlyDoubleQuote], \
\[OpenCurlyDoubleQuote]TH2FData\[CloseCurlyDoubleQuote], ",
  FontFamily->"Courier New"],
 StyleBox["hist",
  FontFamily->"Courier New",
  FontSlant->"Italic"],
 StyleBox["} ],\n  Import[ ",
  FontFamily->"Courier New"],
 StyleBox["file",
  FontFamily->"Courier New",
  FontSlant->"Italic"],
 StyleBox[", {\[OpenCurlyDoubleQuote]ROOT\[CloseCurlyDoubleQuote], \
\[OpenCurlyDoubleQuote]TH2FGraphics\[CloseCurlyDoubleQuote], ",
  FontFamily->"Courier New"],
 StyleBox["hist",
  FontFamily->"Courier New",
  FontSlant->"Italic"],
 StyleBox["} ]",
  FontFamily->"Courier New"],
 "\nwhere:\n    ",
 StyleBox["hist",
  FontSlant->"Italic"],
 "  is the name of the TH2F object."
}], "Text",
 CellChangeTimes->{{3.495468497648314*^9, 3.495468500528111*^9}, {
   3.495468563465575*^9, 3.495468647615963*^9}, {3.495468706668795*^9, 
   3.495468844049102*^9}, {3.498483935097855*^9, 3.498483937281838*^9}, {
   3.4984839819621143`*^9, 3.498484083096613*^9}, {3.4984847206013823`*^9, 
   3.498484782440452*^9}, {3.498496219124737*^9, 3.498496220755698*^9}, {
   3.498499361837543*^9, 3.498499364531248*^9}, {3.4984993962509413`*^9, 
   3.498499434835371*^9}, {3.498844524513542*^9, 3.498844572298003*^9}, {
   3.50272261343639*^9, 3.5027226192773724`*^9}, 3.502723335416308*^9},
 FontFamily->"Courier [ibm]",
 FontSize->10],

Cell[BoxData[
 RowBox[{
  RowBox[{"SetDirectory", "[", 
   RowBox[{"NotebookDirectory", "[", "]"}], "]"}], ";"}]], "Input"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "This", " ", "imports", " ", "the", " ", "histogram", " ", "data", " ", 
    "of", " ", "a", " ", "given", " ", "TH2F", " ", 
    RowBox[{"object", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"data", " ", "=", " ", 
    RowBox[{"Import", "[", 
     RowBox[{"\"\<th2f.root\>\"", ",", " ", 
      RowBox[{"{", 
       RowBox[{"\"\<ROOT\>\"", ",", "\"\<TH2FData\>\"", ",", "\"\<h2\>\""}], 
       "}"}]}], "]"}]}], ";"}]}]], "Input",
 CellFrame->{{0, 0}, {0, 0.5}},
 CellChangeTimes->{{3.498484126665839*^9, 3.498484166433033*^9}, {
   3.4984845171400967`*^9, 3.498484517445868*^9}, {3.498484662021961*^9, 
   3.498484674276703*^9}, {3.498490503553673*^9, 3.498490506542944*^9}, 
   3.498496298032745*^9, {3.498499443423614*^9, 3.498499448203699*^9}, {
   3.4988445926497173`*^9, 3.498844654989193*^9}, {3.4989268963148975`*^9, 
   3.498926902330446*^9}, {3.5000537097865295`*^9, 3.5000537112083864`*^9}, {
   3.5006550928645*^9, 3.500655093208188*^9}, {3.5018694958752975`*^9, 
   3.5018694996564994`*^9}, {3.5025436836694193`*^9, 3.502543690418599*^9}, {
   3.5027226273672895`*^9, 3.502722685777113*^9}}],

Cell["\<\
The data is of the form:
  { {x1, \[CapitalDelta]x1, count1, error1}, {x2, \[CapitalDelta]x2, count2, \
error2}, ... }\
\>", "Text",
 CellChangeTimes->{{3.495468497648314*^9, 3.495468500528111*^9}, {
   3.495468563465575*^9, 3.495468647615963*^9}, {3.495468706668795*^9, 
   3.495468844049102*^9}, {3.498483935097855*^9, 3.498483937281838*^9}, {
   3.4984839819621143`*^9, 3.498484083096613*^9}, {3.4984847206013823`*^9, 
   3.498484782440452*^9}, {3.498496219124737*^9, 3.498496220755698*^9}, {
   3.498499361837543*^9, 3.498499364531248*^9}, {3.4984993962509413`*^9, 
   3.498499434835371*^9}, {3.498844524513542*^9, 3.498844572298003*^9}, {
   3.498844755939704*^9, 3.4988447752899303`*^9}, 3.5025693259032607`*^9},
 FontFamily->"Courier [ibm]",
 FontSize->10],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "show", " ", "first", " ", "5", " ", "entries", " ", "in", " ", "a", " ", 
    "grid"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"head", "=", 
     RowBox[{"{", 
      RowBox[{
      "\"\<x\>\"", ",", "\"\<\[CapitalDelta]x\>\"", ",", "\"\<y\>\"", ",", 
       "\"\<\[CapitalDelta]y\>\"", ",", "\"\<count\>\"", ",", 
       "\"\<\[CapitalDelta]count\>\""}], "}"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{"Grid", "[", 
    RowBox[{
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"{", "head", "}"}], ",", 
       RowBox[{"Take", "[", 
        RowBox[{"data", ",", "5"}], "]"}]}], "]"}], ",", 
     RowBox[{"Frame", "\[Rule]", " ", "All"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{{3.502722709362775*^9, 3.5027227714066067`*^9}}],

Cell[BoxData[
 TagBox[GridBox[{
    {"\<\"x\"\>", "\<\"\[CapitalDelta]x\"\>", "\<\"y\"\>", "\<\"\
\[CapitalDelta]y\"\>", "\<\"count\"\>", "\<\"\[CapitalDelta]count\"\>"},
    {
     RowBox[{"-", "4.`"}], "0.4`", 
     RowBox[{"-", "4.`"}], "0.4`", "1.`", "1.`"},
    {
     RowBox[{"-", "4.`"}], "0.4`", 
     RowBox[{"-", "3.6`"}], "0.4`", "11.`", "3.3166247903554`"},
    {
     RowBox[{"-", "4.`"}], "0.4`", 
     RowBox[{"-", "3.2`"}], "0.4`", "16.`", "4.`"},
    {
     RowBox[{"-", "4.`"}], "0.4`", 
     RowBox[{"-", "2.8`"}], "0.4`", "12.`", "3.4641016151377544`"},
    {
     RowBox[{"-", "4.`"}], "0.4`", 
     RowBox[{"-", "2.4`"}], "0.4`", "9.`", "3.`"}
   },
   AutoDelete->False,
   GridBoxFrame->{"Columns" -> {{True}}, "Rows" -> {{True}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
  "Grid"]], "Output",
 CellChangeTimes->{3.502722772031419*^9, 3.5027265676848536`*^9, 
  3.502726777910019*^9, 3.502726843428113*^9, 3.502735490828591*^9, 
  3.502735905373883*^9, 3.50635014144654*^9, 3.5063504145119004`*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Import", " ", "the", " ", "histogram", " ", "directly", " ", "as", " ", 
    "a", " ", "Graphics"}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"graphics3D", "=", 
   RowBox[{"Import", "[", 
    RowBox[{"\"\<th2f.root\>\"", ",", 
     RowBox[{"{", 
      RowBox[{
      "\"\<ROOT\>\"", ",", "\"\<TH2FGraphics\>\"", ",", "\"\<h2\>\""}], 
      "}"}]}], "]"}]}]}]], "Input",
 CellFrame->{{0, 0}, {0, 0.5}},
 CellChangeTimes->{{3.498484126665839*^9, 3.498484166433033*^9}, {
   3.4984845171400967`*^9, 3.498484517445868*^9}, {3.498484662021961*^9, 
   3.498484674276703*^9}, {3.498490503553673*^9, 3.498490506542944*^9}, 
   3.498496298032745*^9, {3.498499443423614*^9, 3.498499448203699*^9}, {
   3.4988445926497173`*^9, 3.498844654989193*^9}, {3.498844800056354*^9, 
   3.498844826445148*^9}, 3.50254383517107*^9, {3.5027227913068695`*^9, 
   3.5027228121599693`*^9}, 3.5027229627084208`*^9, {3.502723037876279*^9, 
   3.5027230734772215`*^9}, {3.507036066676117*^9, 3.507036067223051*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Options", " ", "available", " ", "to", " ", 
    RowBox[{"Histogram3D", "[", "]"}], " ", "can", " ", "be", " ", "passed", 
    " ", 
    RowBox[{"directly", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"graphics", "=", 
   RowBox[{"Import", "[", 
    RowBox[{"\"\<th2f.root\>\"", ",", 
     RowBox[{"{", 
      RowBox[{
      "\"\<ROOT\>\"", ",", "\"\<TH2FGraphics\>\"", ",", "\"\<h2\>\""}], "}"}],
      ",", 
     RowBox[{"ChartElements", "\[Rule]", 
      RowBox[{"Graphics3D", "@", 
       RowBox[{"Cuboid", "[", "]"}]}]}], ",", 
     RowBox[{"ChartStyle", "\[Rule]", "\"\<Pastel\>\""}]}], 
    "]"}]}]}]], "Input",
 CellFrame->{{0, 0}, {0, 0.5}},
 CellChangeTimes->{{3.498484126665839*^9, 3.498484166433033*^9}, {
   3.4984845171400967`*^9, 3.498484517445868*^9}, {3.498484662021961*^9, 
   3.498484674276703*^9}, {3.498490503553673*^9, 3.498490506542944*^9}, 
   3.498496298032745*^9, {3.498499443423614*^9, 3.498499448203699*^9}, {
   3.4988445926497173`*^9, 3.498844654989193*^9}, {3.498844800056354*^9, 
   3.498844826445148*^9}, 3.50254383517107*^9, {3.5027227913068695`*^9, 
   3.5027228121599693`*^9}, {3.5027229627084208`*^9, 
   3.5027229805624237`*^9}, {3.5027230575591164`*^9, 
   3.5027230881143794`*^9}, {3.5027265324285364`*^9, 
   3.5027265579799895`*^9}, {3.5027266012221117`*^9, 
   3.5027266066137033`*^9}, {3.502735535610414*^9, 3.5027355438448944`*^9}, 
   3.5027355747045755`*^9, {3.5063501722730865`*^9, 3.506350175366684*^9}}]
}, Closed]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{1172, 777},
WindowMargins->{{206, Automatic}, {-85, Automatic}},
Magnification:>FEPrivate`If[
  FEPrivate`Equal[FEPrivate`$VersionNumber, 6.], 1.25, 1.25 Inherited],
FrontEndVersion->"8.0 for Microsoft Windows (32-bit) (November 7, 2010)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[579, 22, 318, 7, 36, "Subsubtitle"],
Cell[900, 31, 145, 5, 76, "Text"],
Cell[1048, 38, 255, 3, 34, "Text"],
Cell[1306, 43, 160, 3, 34, "Text"],
Cell[CellGroupData[{
Cell[1491, 50, 200, 3, 58, "Input"],
Cell[1694, 55, 237, 4, 35, "Output"],
Cell[1934, 61, 255, 4, 35, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2226, 70, 1121, 31, 102, "Input"],
Cell[3350, 103, 285, 5, 35, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3672, 113, 229, 3, 88, "Section"],
Cell[CellGroupData[{
Cell[3926, 120, 178, 2, 46, "Subsection"],
Cell[4107, 124, 1320, 30, 134, "Text"],
Cell[5430, 156, 123, 3, 35, "Input"],
Cell[5556, 161, 427, 6, 55, "Text"],
Cell[CellGroupData[{
Cell[6008, 171, 739, 12, 35, "Input"],
Cell[6750, 185, 876, 15, 35, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[7663, 205, 938, 15, 35, "Input"],
Cell[8604, 222, 3247, 68, 102, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[11888, 295, 179, 3, 35, "Input"],
Cell[12070, 300, 338, 7, 35, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[12457, 313, 243, 3, 35, "Subsection"],
Cell[CellGroupData[{
Cell[12725, 320, 356, 5, 32, "Subsubsection"],
Cell[13084, 327, 4103, 114, 374, "Text"],
Cell[17190, 443, 666, 12, 53, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[17893, 460, 331, 6, 23, "Subsubsection"],
Cell[CellGroupData[{
Cell[18249, 470, 949, 19, 69, "Input"],
Cell[19201, 491, 1625, 31, 227, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[20863, 527, 1113, 29, 102, "Input"],
Cell[21979, 558, 1151, 20, 266, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[23179, 584, 476, 6, 23, "Subsubsection"],
Cell[CellGroupData[{
Cell[23680, 594, 1109, 24, 91, "Input"],
Cell[24792, 620, 15614, 478, 302, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[40455, 1104, 547, 9, 23, "Subsubsection"],
Cell[CellGroupData[{
Cell[41027, 1117, 1315, 23, 46, "Input"],
Cell[42345, 1142, 308, 7, 27, "Print"],
Cell[42656, 1151, 562, 10, 35, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[43267, 1167, 385, 7, 23, "Subsubsection"],
Cell[CellGroupData[{
Cell[43677, 1178, 1403, 29, 91, "Input"],
Cell[45083, 1209, 834, 18, 35, "Output"],
Cell[45920, 1229, 802, 18, 35, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[46771, 1253, 455, 7, 23, "Subsubsection"],
Cell[CellGroupData[{
Cell[47251, 1264, 1084, 22, 69, "Input"],
Cell[48338, 1288, 573, 13, 35, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[48960, 1307, 407, 5, 23, "Subsubsection"],
Cell[49370, 1314, 949, 21, 58, "Input"],
Cell[CellGroupData[{
Cell[50344, 1339, 1115, 26, 80, "Input"],
Cell[51462, 1367, 1973, 42, 327, "Output"]
}, Open  ]],
Cell[53450, 1412, 1011, 21, 211, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[54498, 1438, 331, 4, 23, "Subsubsection"],
Cell[CellGroupData[{
Cell[54854, 1446, 822, 19, 69, "Input"],
Cell[55679, 1467, 145, 2, 27, "Print"],
Cell[55827, 1471, 805, 12, 35, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[56669, 1488, 740, 17, 69, "Input"],
Cell[57412, 1507, 875, 18, 50, "Print"],
Cell[58290, 1527, 408, 6, 35, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[58735, 1538, 921, 21, 69, "Input"],
Cell[CellGroupData[{
Cell[59681, 1563, 369, 8, 27, "Print"],
Cell[60053, 1573, 471, 10, 27, "Print"]
}, Open  ]],
Cell[60539, 1586, 222, 3, 35, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[60822, 1596, 290, 4, 46, "Subsection"],
Cell[61115, 1602, 1539, 40, 114, "Text"],
Cell[62657, 1644, 123, 3, 35, "Input"],
Cell[62783, 1649, 1175, 23, 69, "Input"],
Cell[63961, 1674, 773, 14, 53, "Text"],
Cell[CellGroupData[{
Cell[64759, 1692, 837, 23, 80, "Input"],
Cell[65599, 1717, 1037, 30, 231, "Output"]
}, Open  ]],
Cell[66651, 1750, 956, 20, 69, "Input"],
Cell[67610, 1772, 1274, 28, 91, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[68921, 1805, 312, 4, 35, "Subsection"],
Cell[69236, 1811, 1586, 40, 177, "Text"],
Cell[70825, 1853, 123, 3, 53, "Input"],
Cell[70951, 1858, 1189, 23, 107, "Input"],
Cell[72143, 1883, 773, 14, 82, "Text"],
Cell[CellGroupData[{
Cell[72941, 1901, 839, 23, 125, "Input"],
Cell[73783, 1926, 1058, 26, 212, "Output"]
}, Open  ]],
Cell[74856, 1955, 1055, 21, 107, "Input"],
Cell[75914, 1978, 1523, 31, 141, "Input"]
}, Closed]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
